@@ -18,12 +18,12 @@
  *
  */
 
-#ifndef _PROCMAN_PROCTABLE_H_
-#define _PROCMAN_PROCTABLE_H_
+#ifndef _GSM_PROCTABLE_H_
+#define _GSM_PROCTABLE_H_
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include "procman-app.h"
+#include "application.h"
 
 enum
 {
@@ -57,19 +57,15 @@ enum
 };
 
 
-GtkWidget*      proctable_new (ProcmanApp *app);
-void            proctable_update_table (ProcmanApp *app);
-void            proctable_update_list (ProcmanApp *app);
-void            proctable_update_all (ProcmanApp *app);
-void            proctable_clear_tree (ProcmanApp *app);
-void            proctable_free_table (ProcmanApp *app);
-void            proctable_freeze (ProcmanApp *app);
-void            proctable_thaw (ProcmanApp *app);
-void            proctable_reset_timeout (ProcmanApp *app);
+GtkWidget*      proctable_new (GsmApplication *app);
+void            proctable_update (GsmApplication *app);
+void            proctable_free_table (GsmApplication *app);
+void            proctable_freeze (GsmApplication *app);
+void            proctable_thaw (GsmApplication *app);
+void            proctable_reset_timeout (GsmApplication *app);
 
-GSList*         proctable_get_columns_order(GtkTreeView *treeview);
-void            proctable_set_columns_order(GtkTreeView *treeview, GSList *order);
+void            get_process_memory_writable (ProcInfo *info);
+void            get_last_selected (GtkTreeModel *model, GtkTreePath *path,
+                                   GtkTreeIter *iter, gpointer data);
 
-char*           make_loadavg_string(void);
-
-#endif /* _PROCMAN_PROCTABLE_H_ */
+#endif /* _GSM_PROCTABLE_H_ */
